ensemble: A probabilistic method to make ensemble predictions.

Description Usage Arguments Value Author(s)

Description

A probabilistic method to make ensemble predictions.

Usage

1
ensemble(df, class1Prob = 0.5)

Arguments

df

A data frame containing the probabilisitic predictions of different methods. Columns are assumed to be methods.

class1Prob

A numeric value that gives the prior probability of observing class 1. Does not change the order of the output.

Value

numeric A vector that contains the ensemble predictions

Author(s)

Guenter Klambauer


bioinf-jku/platt documentation built on May 12, 2019, 9:24 p.m.