Description Usage Arguments Value Author(s)
Identifies coefficients of the sigmoid for Platt scaling.
1 | plattScaling(predictions, labels)
|
predictions |
A numeric vector containing the prediction values from any machine learning method. |
labels |
The labels of the data. Should be a vector containing only zeros and ones, or a logical vector |
list A list containing the parameters of the sigmoid A and B, and the Platt-scaled prediction values.
Guenter Klambauer
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.