predictProb: Platt scaling of prediction values using precalculated...

Description Usage Arguments Value Author(s)

Description

This function performs the mapping of the prediction values to the sigmoid using the coefficients determined by the function "plattScaling".

Usage

1
predictProb(A, B, predictions)

Arguments

A

The parameter A of the sigmoid function. A single numeric is expected.

B

The parameter A of the sigmoid function. A single numeric is expected.

predictions

A vector of prediction values typically from a test set. A numeric vector ist expected

Value

numeric A numeric vector containing the Platt-scaled values.

Author(s)

Guenter Klambauer


bioinf-jku/platt documentation built on May 12, 2019, 9:24 p.m.