Description Usage Arguments Value Author(s)
A probabilistic method to make ensemble predictions.
1 |
df |
A data frame containing the probabilisitic predictions of different methods. Columns are assumed to be methods. |
class1Prob |
A numeric value that gives the prior probability of observing class 1. Does not change the order of the output. |
numeric A vector that contains the ensemble predictions
Guenter Klambauer
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.