This package implements a fast and robust function to estimate the parameters of a sigmoid function that can map prediction values from arbitrary machine learning methods to probabilistic predictions.
| Package: | platt |
| Type: | Package |
| Version: | 0.99.0 |
| Date: | 2015-01-07 |
| License: | LGPL (>= 2.0) |
The package contains a testing data set MMP. The core function ist "plattScaling" that fits the sigmoid function. Additionally the functions "predictProb" is provided to map new values to the sigmoid and the function "ensemble" combines multiple probabilstic predicitons into one predcition.
Guenter Klambauer and Andreas Mayr.
Maintainer: <klambauer@bioinf.jku.at>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.