Description Usage Arguments Value Author(s)
This function performs the mapping of the prediction values to the sigmoid using the coefficients determined by the function "plattScaling".
1 | predictProb(A, B, predictions)
|
A |
The parameter A of the sigmoid function. A single numeric is expected. |
B |
The parameter A of the sigmoid function. A single numeric is expected. |
predictions |
A vector of prediction values typically from a test set. A numeric vector ist expected |
numeric A numeric vector containing the Platt-scaled values.
Guenter Klambauer
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.